@@ -231,7 +231,7 @@ def make_histogram(values, bins, max_bins=None):
         limits = new_limits
 
     # Find the first and the last bin defining the support of the histogram:
-    cum_counts = np.cumsum(np.greater(counts, 0, dtype=np.int32))
+    cum_counts = np.cumsum(np.greater(counts, 0))
     start, end = np.searchsorted(cum_counts, [0, cum_counts[-1] - 1], side="right")
     start = int(start)
     end = int(end) + 1
@@ -365,6 +365,8 @@ def make_video(tensor, fps):
         print("moviepy is installed, but can't import moviepy.editor.",
               "Some packages could be missing [imageio, requests]")
         return
+
+    import moviepy.version
     import tempfile
 
     t, h, w, c = tensor.shape
@@ -374,12 +376,15 @@ def make_video(tensor, fps):
 
     filename = tempfile.NamedTemporaryFile(suffix='.gif', delete=False).name
 
-    # moviepy >= 1.0.0 use logger=None to suppress output.
-    try:
-        clip.write_gif(filename, verbose=False, logger=None)
-    except TypeError:
+    if moviepy.version.__version__.startswith("0."):
         logging.warning('Upgrade to moviepy >= 1.0.0 to supress the progress bar.')
         clip.write_gif(filename, verbose=False)
+    elif moviepy.version.__version__.startswith("1."):
+        # moviepy >= 1.0.0 use logger=None to suppress output.
+        clip.write_gif(filename, verbose=False, logger=None)
+    else:
+        # Moviepy >= 2.0.0.dev1 removed the verbose argument
+        clip.write_gif(filename, logger=None)
 
     with open(filename, 'rb') as f:
         tensor_string = f.read()
@@ -505,7 +510,7 @@ def compute_curve(labels, predictions, num_thresholds=None, weights=None):
 
     # Compute bins of true positives and false positives.
     bucket_indices = np.int32(np.floor(predictions * (num_thresholds - 1)))
-    float_labels = labels.astype(np.float)
+    float_labels = labels.astype(float)
     histogram_range = (0, num_thresholds - 1)
     tp_buckets, _ = np.histogram(
         bucket_indices,
